@@ -14,30 +14,33 @@
 #include <unistd.h>
 
 #ifdef PSUTIL_AIX
-    #include "arch/aix/ifaddrs.h"
+#include "arch/aix/ifaddrs.h"
 #else
-    #include <ifaddrs.h>
+#include <ifaddrs.h>
 #endif
 
 #if defined(PSUTIL_LINUX)
-    #include <netdb.h>
-    #include <linux/types.h>
-    #include <linux/if_packet.h>
+#include <netdb.h>
+#include <linux/types.h>
+#include <linux/if_packet.h>
 #endif
+
 #if defined(PSUTIL_BSD) || defined(PSUTIL_OSX)
-    #include <netdb.h>
-    #include <netinet/in.h>
-    #include <net/if_dl.h>
-    #include <sys/sockio.h>
-    #include <net/if_media.h>
-    #include <net/if.h>
+#include <netdb.h>
+#include <netinet/in.h>
+#include <net/if_dl.h>
+#include <sys/sockio.h>
+#include <net/if_media.h>
+#include <net/if.h>
 #endif
+
 #if defined(PSUTIL_SUNOS)
-    #include <netdb.h>
-    #include <sys/sockio.h>
+#include <netdb.h>
+#include <sys/sockio.h>
 #endif
+
 #if defined(PSUTIL_AIX)
-    #include <netdb.h>
+#include <netdb.h>
 #endif
 
 #include "../../arch/all/init.h"
@@ -66,13 +69,14 @@ psutil_convert_ipaddr(struct sockaddr *addr, int family) {
             addrlen = sizeof(struct sockaddr_in);
         else
             addrlen = sizeof(struct sockaddr_in6);
-        err = getnameinfo(addr, addrlen, buf, sizeof(buf), NULL, 0,
-                          NI_NUMERICHOST);
+        err = getnameinfo(
+            addr, addrlen, buf, sizeof(buf), NULL, 0, NI_NUMERICHOST
+        );
         if (err != 0) {
             // XXX we get here on FreeBSD when processing 'lo' / AF_INET6
             // broadcast. Not sure what to do other than returning None.
             // ifconfig does not show anything BTW.
-            // PyErr_Format(PyExc_RuntimeError, gai_strerror(err));
+            // psutil_runtime_error(gai_strerror(err));
             // return NULL;
             Py_INCREF(Py_None);
             return Py_None;
@@ -106,7 +110,7 @@ psutil_convert_ipaddr(struct sockaddr *addr, int family) {
     if (len > 0) {
         ptr = buf;
         for (n = 0; n < len; ++n) {
-            sprintf(ptr, "%02x:", data[n] & 0xff);
+            str_format(ptr, sizeof(ptr), "%02x:", data[n] & 0xff);
             ptr += 3;
         }
         *--ptr = '\0';
@@ -123,8 +127,8 @@ psutil_convert_ipaddr(struct sockaddr *addr, int family) {
  * Return NICs information a-la ifconfig as a list of tuples.
  * TODO: on Solaris we won't get any MAC address.
  */
-PyObject*
-psutil_net_if_addrs(PyObject* self, PyObject* args) {
+PyObject *
+psutil_net_if_addrs(PyObject *self, PyObject *args) {
     struct ifaddrs *ifaddr, *ifa;
     int family;
 
@@ -138,7 +142,7 @@ psutil_net_if_addrs(PyObject* self, PyObject* args) {
     if (py_retlist == NULL)
         return NULL;
     if (getifaddrs(&ifaddr) == -1) {
-        PyErr_SetFromErrno(PyExc_OSError);
+        psutil_oserror();
         goto error;
     }
 
@@ -186,7 +190,7 @@ psutil_net_if_addrs(PyObject* self, PyObject* args) {
             py_ptp
         );
 
-        if (! py_tuple)
+        if (!py_tuple)
             goto error;
         if (PyList_Append(py_retlist, py_tuple))
             goto error;
@@ -224,14 +228,14 @@ psutil_net_if_mtu(PyObject *self, PyObject *args) {
     int ret;
     struct ifreq ifr;
 
-    if (! PyArg_ParseTuple(args, "s", &nic_name))
+    if (!PyArg_ParseTuple(args, "s", &nic_name))
         return NULL;
 
     sock = socket(AF_INET, SOCK_DGRAM, 0);
     if (sock == -1)
         goto error;
 
-    PSUTIL_STRNCPY(ifr.ifr_name, nic_name, sizeof(ifr.ifr_name));
+    str_copy(ifr.ifr_name, sizeof(ifr.ifr_name), nic_name);
     ret = ioctl(sock, SIOCGIFMTU, &ifr);
     if (ret == -1)
         goto error;
@@ -242,16 +246,15 @@ psutil_net_if_mtu(PyObject *self, PyObject *args) {
 error:
     if (sock != -1)
         close(sock);
-    return PyErr_SetFromErrno(PyExc_OSError);
+    return psutil_oserror();
 }
 
 static int
-append_flag(PyObject *py_retlist, const char *flag_name)
-{
+append_flag(PyObject *py_retlist, const char *flag_name) {
     PyObject *py_str = NULL;
 
     py_str = PyUnicode_FromString(flag_name);
-    if (! py_str)
+    if (!py_str)
         return 0;
     if (PyList_Append(py_retlist, py_str)) {
         Py_DECREF(py_str);
@@ -277,19 +280,19 @@ psutil_net_if_flags(PyObject *self, PyObject *args) {
     if (py_retlist == NULL)
         return NULL;
 
-    if (! PyArg_ParseTuple(args, "s", &nic_name))
+    if (!PyArg_ParseTuple(args, "s", &nic_name))
         goto error;
 
     sock = socket(AF_INET, SOCK_DGRAM, 0);
     if (sock == -1) {
-        psutil_PyErr_SetFromOSErrnoWithSyscall("socket(SOCK_DGRAM)");
+        psutil_oserror_wsyscall("socket(SOCK_DGRAM)");
         goto error;
     }
 
-    PSUTIL_STRNCPY(ifr.ifr_name, nic_name, sizeof(ifr.ifr_name));
+    str_copy(ifr.ifr_name, sizeof(ifr.ifr_name), nic_name);
     ret = ioctl(sock, SIOCGIFFLAGS, &ifr);
     if (ret == -1) {
-        psutil_PyErr_SetFromOSErrnoWithSyscall("ioctl(SIOCGIFFLAGS)");
+        psutil_oserror_wsyscall("ioctl(SIOCGIFFLAGS)");
         goto error;
     }
 
@@ -298,10 +301,14 @@ psutil_net_if_flags(PyObject *self, PyObject *args) {
 
     flags = ifr.ifr_flags & 0xFFFF;
 
-    // Linux/glibc IFF flags: https://sourceware.org/git/?p=glibc.git;a=blob;f=sysdeps/gnu/net/if.h;h=251418f82331c0426e58707fe4473d454893b132;hb=HEAD
-    // macOS IFF flags: https://opensource.apple.com/source/xnu/xnu-792/bsd/net/if.h.auto.html
-    // AIX IFF flags: https://www.ibm.com/support/pages/how-hexadecimal-flags-displayed-ifconfig-are-calculated
-    // FreeBSD IFF flags: https://www.freebsd.org/cgi/man.cgi?query=if_allmulti&apropos=0&sektion=0&manpath=FreeBSD+10-current&format=html
+    // Linux/glibc IFF flags:
+    // https://sourceware.org/git/?p=glibc.git;a=blob;f=sysdeps/gnu/net/if.h;h=251418f82331c0426e58707fe4473d454893b132;hb=HEAD
+    // macOS IFF flags:
+    // https://opensource.apple.com/source/xnu/xnu-792/bsd/net/if.h.auto.html
+    // AIX IFF flags:
+    // https://www.ibm.com/support/pages/how-hexadecimal-flags-displayed-ifconfig-are-calculated
+    // FreeBSD IFF flags:
+    // https://www.freebsd.org/cgi/man.cgi?query=if_allmulti&apropos=0&sektion=0&manpath=FreeBSD+10-current&format=html
 
 #ifdef IFF_UP
     // Available in (at least) Linux, macOS, AIX, BSD
@@ -458,14 +465,14 @@ psutil_net_if_is_running(PyObject *self, PyObject *args) {
     int ret;
     struct ifreq ifr;
 
-    if (! PyArg_ParseTuple(args, "s", &nic_name))
+    if (!PyArg_ParseTuple(args, "s", &nic_name))
         return NULL;
 
     sock = socket(AF_INET, SOCK_DGRAM, 0);
     if (sock == -1)
         goto error;
 
-    PSUTIL_STRNCPY(ifr.ifr_name, nic_name, sizeof(ifr.ifr_name));
+    str_copy(ifr.ifr_name, sizeof(ifr.ifr_name), nic_name);
     ret = ioctl(sock, SIOCGIFFLAGS, &ifr);
     if (ret == -1)
         goto error;
@@ -479,86 +486,87 @@ psutil_net_if_is_running(PyObject *self, PyObject *args) {
 error:
     if (sock != -1)
         close(sock);
-    return PyErr_SetFromErrno(PyExc_OSError);
+    return psutil_oserror();
 }
 
 
-
 // net_if_stats() macOS/BSD implementation.
 #ifdef PSUTIL_HAS_NET_IF_DUPLEX_SPEED
 
-int psutil_get_nic_speed(int ifm_active) {
+int
+psutil_get_nic_speed(int ifm_active) {
     // Determine NIC speed. Taken from:
     // http://www.i-scream.org/libstatgrab/
     // Assuming only ETHER devices
-    switch(IFM_TYPE(ifm_active)) {
+    switch (IFM_TYPE(ifm_active)) {
         case IFM_ETHER:
-            switch(IFM_SUBTYPE(ifm_active)) {
-#if defined(IFM_HPNA_1) && ((!defined(IFM_10G_LR)) \
-    || (IFM_10G_LR != IFM_HPNA_1))
+            switch (IFM_SUBTYPE(ifm_active)) {
+#if defined(IFM_HPNA_1) \
+    && ((!defined(IFM_10G_LR)) || (IFM_10G_LR != IFM_HPNA_1))
                 // HomePNA 1.0 (1Mb/s)
-                case(IFM_HPNA_1):
+                case (IFM_HPNA_1):
                     return 1;
 #endif
                 // 10 Mbit
-                case(IFM_10_T):  // 10BaseT - RJ45
-                case(IFM_10_2):  // 10Base2 - Thinnet
-                case(IFM_10_5):  // 10Base5 - AUI
-                case(IFM_10_STP):  // 10BaseT over shielded TP
-                case(IFM_10_FL):  // 10baseFL - Fiber
+                case (IFM_10_T):  // 10BaseT - RJ45
+                case (IFM_10_2):  // 10Base2 - Thinnet
+                case (IFM_10_5):  // 10Base5 - AUI
+                case (IFM_10_STP):  // 10BaseT over shielded TP
+                case (IFM_10_FL):  // 10baseFL - Fiber
                     return 10;
                 // 100 Mbit
-                case(IFM_100_TX):  // 100BaseTX - RJ45
-                case(IFM_100_FX):  // 100BaseFX - Fiber
-                case(IFM_100_T4):  // 100BaseT4 - 4 pair cat 3
-                case(IFM_100_VG):  // 100VG-AnyLAN
-                case(IFM_100_T2):  // 100BaseT2
+                case (IFM_100_TX):  // 100BaseTX - RJ45
+                case (IFM_100_FX):  // 100BaseFX - Fiber
+                case (IFM_100_T4):  // 100BaseT4 - 4 pair cat 3
+                case (IFM_100_VG):  // 100VG-AnyLAN
+                case (IFM_100_T2):  // 100BaseT2
                     return 100;
                 // 1000 Mbit
-                case(IFM_1000_SX):  // 1000BaseSX - multi-mode fiber
-                case(IFM_1000_LX):  // 1000baseLX - single-mode fiber
-                case(IFM_1000_CX):  // 1000baseCX - 150ohm STP
+                case (IFM_1000_SX):  // 1000BaseSX - multi-mode fiber
+                case (IFM_1000_LX):  // 1000baseLX - single-mode fiber
+                case (IFM_1000_CX):  // 1000baseCX - 150ohm STP
 #if defined(IFM_1000_TX) && !defined(PSUTIL_OPENBSD)
-                #define HAS_CASE_IFM_1000_TX 1
-                // FreeBSD 4 and others (but NOT OpenBSD) -> #define IFM_1000_T in net/if_media.h
-                case(IFM_1000_TX):
+#define HAS_CASE_IFM_1000_TX 1
+                // FreeBSD 4 and others (but NOT OpenBSD) -> #define IFM_1000_T
+                // in net/if_media.h
+                case (IFM_1000_TX):
 #endif
 #ifdef IFM_1000_FX
-                case(IFM_1000_FX):
+                case (IFM_1000_FX):
 #endif
 #if defined(IFM_1000_T) && (!HAS_CASE_IFM_1000_TX || IFM_1000_T != IFM_1000_TX)
-                case(IFM_1000_T):
+                case (IFM_1000_T):
 #endif
                     return 1000;
 #if defined(IFM_10G_SR) || defined(IFM_10G_LR) || defined(IFM_10G_CX4) \
-         || defined(IFM_10G_T)
+    || defined(IFM_10G_T)
 #ifdef IFM_10G_SR
-                case(IFM_10G_SR):
+                case (IFM_10G_SR):
 #endif
 #ifdef IFM_10G_LR
-                case(IFM_10G_LR):
+                case (IFM_10G_LR):
 #endif
 #ifdef IFM_10G_CX4
-                case(IFM_10G_CX4):
+                case (IFM_10G_CX4):
 #endif
 #ifdef IFM_10G_TWINAX
-                case(IFM_10G_TWINAX):
+                case (IFM_10G_TWINAX):
 #endif
 #ifdef IFM_10G_TWINAX_LONG
-                case(IFM_10G_TWINAX_LONG):
+                case (IFM_10G_TWINAX_LONG):
 #endif
 #ifdef IFM_10G_T
-                case(IFM_10G_T):
+                case (IFM_10G_T):
 #endif
                     return 10000;
 #endif
 #if defined(IFM_2500_SX)
 #ifdef IFM_2500_SX
-                case(IFM_2500_SX):
+                case (IFM_2500_SX):
 #endif
                     return 2500;
-#endif // any 2.5GBit stuff...
-                // We don't know what it is
+#endif  // any 2.5GBit stuff...
+        // We don't know what it is
                 default:
                     return 0;
             }
@@ -566,7 +574,7 @@ int psutil_get_nic_speed(int ifm_active) {
 
 #ifdef IFM_TOKEN
         case IFM_TOKEN:
-            switch(IFM_SUBTYPE(ifm_active)) {
+            switch (IFM_SUBTYPE(ifm_active)) {
                 case IFM_TOK_STP4:  // Shielded twisted pair 4m - DB9
                 case IFM_TOK_UTP4:  // Unshielded twisted pair 4m - RJ45
                     return 4;
@@ -591,7 +599,7 @@ int psutil_get_nic_speed(int ifm_active) {
 
 #ifdef IFM_FDDI
         case IFM_FDDI:
-            switch(IFM_SUBTYPE(ifm_active)) {
+            switch (IFM_SUBTYPE(ifm_active)) {
                 // We don't know what it is
                 default:
                     return 0;
@@ -599,7 +607,7 @@ int psutil_get_nic_speed(int ifm_active) {
             break;
 #endif
         case IFM_IEEE80211:
-            switch(IFM_SUBTYPE(ifm_active)) {
+            switch (IFM_SUBTYPE(ifm_active)) {
                 case IFM_IEEE80211_FH1:  // Frequency Hopping 1Mbps
                 case IFM_IEEE80211_DS1:  // Direct Sequence 1Mbps
                     return 1;
@@ -639,17 +647,17 @@ psutil_net_if_duplex_speed(PyObject *self, PyObject *args) {
     struct ifreq ifr;
     struct ifmediareq ifmed;
 
-    if (! PyArg_ParseTuple(args, "s", &nic_name))
+    if (!PyArg_ParseTuple(args, "s", &nic_name))
         return NULL;
 
     sock = socket(AF_INET, SOCK_DGRAM, 0);
     if (sock == -1)
-        return PyErr_SetFromErrno(PyExc_OSError);
-    PSUTIL_STRNCPY(ifr.ifr_name, nic_name, sizeof(ifr.ifr_name));
+        return psutil_oserror();
+    str_copy(ifr.ifr_name, sizeof(ifr.ifr_name), nic_name);
 
     // speed / duplex
     memset(&ifmed, 0, sizeof(struct ifmediareq));
-    strlcpy(ifmed.ifm_name, nic_name, sizeof(ifmed.ifm_name));
+    str_copy(ifmed.ifm_name, sizeof(ifmed.ifm_name), nic_name);
     ret = ioctl(sock, SIOCGIFMEDIA, (caddr_t)&ifmed);
     if (ret == -1) {
         speed = 0;
